// ----------------------------------------------------------------------------
/**
   File: battery.h
  
   System:         DS277x based battery pack header file
   Language: C
  
   Licensed Material - Property of Marko Pavlin Hardware Pages. No restrictions for 
   members of Electronic society of Slovenia
   
   Uporaba izvorne kode je za lane drutva elektronikov slovenije brez licennih omejitev.
  
   (c) Copyright  Marko Pavlin (C)2009
  
   Address:
   		http://www.feltna.com/hardware
   		E-Mail: development@pavlin.si
  
   Author: Marko Pavlin
   E-Mail (or paypal donations): marko@pavlin.si
  
   Description: Battery gauge and protection DS277x driver
   
   Limitations: Only I2C supported
  
*/  

#ifndef __BATTERY_H__
#define __BATTERY_H__


// Status register bit maasks
#define BAT_PORF 	0x02


#define BAT_EEPROM_STARTADDRESS 0x61
#define BAT_EEPROM_LENGTH 30

enum 
{
	BAT_LP7545135_4500,
	BAT_LP755085_3300,
};

BYTE Battery_status(void);
BYTE Battery_protection(void);
float Battery_voltage(BYTE cell);
float Battery_temperature(void);
float Battery_current(float Rsense, BYTE average);
float Battery_acumulated_current(float Rsense);
BYTE Battery_cycles(void);
float Battery_remaining(BYTE RAAC);
BYTE Battery_RARC(void);
BYTE Battery_RSRC(void);
float Battery_GetVov(void);
void Battery_SetVov(float vov);
BYTE Battery_GetVuv(void);
void Battery_SetVuv(BYTE vuv);
BYTE Battery_Init(int BAT_id);

/* Undervolatage protection tresholds */
enum 
{
	BATTERY_VUV200 = 0,			// 2.00V
	BATTERY_VUV230,				// 2.30V
	BATTERY_VUV245,				// 2.45V
	BATTERY_VUV260,				// 2.60V
};

#endif

/*------------------------------------------------------------------*/
/* End of file                                                      */
/*------------------------------------------------------------------*/

